@@ -3,6 +3,7 @@ use crate::Vec3;
 use auto_ops::*;
 
 #[derive(Debug, Clone, Copy, PartialEq)]
+#[cfg_attr(feature="serde", derive(serde::Serialize, serde::Deserialize))]
 #[repr(C)]
 pub struct Quaternion {
     pub x: f32,
@@ -103,3 +104,9 @@ impl_op_ex!(- |a: &Quaternion| -> Quaternion {
         w: a.w,
     }
 });
+
+impl From<[f32; 4]> for Quaternion {
+    fn from(d: [f32; 4]) -> Self {
+        Self{x: d[0], y: d[1], z: d[2], w: d[3]}
+    }
+}
