@@ -3,6 +3,7 @@ use std::ops::Neg;
 use auto_ops::*;
 
 #[derive(Debug, Clone, Copy, PartialEq)]
+#[cfg_attr(feature="serde", derive(serde::Serialize, serde::Deserialize))]
 #[repr(C)]
 pub struct Vec2 {
     pub x: f32,
@@ -85,6 +86,12 @@ impl Neg for Vec2 {
     }
 }
 
+impl From<[f32; 2]> for Vec2 {
+    fn from(d: [f32; 2]) -> Self {
+        Self{x: d[0], y: d[1]}
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
