@@ -3,6 +3,7 @@ use std::ops::Neg;
 use auto_ops::*;
 
 #[derive(Debug, Clone, Copy, PartialEq)]
+#[cfg_attr(feature="serde", derive(serde::Serialize, serde::Deserialize))]
 #[repr(C)]
 pub struct Vec4 {
     pub x: f32,
@@ -89,6 +90,12 @@ impl Neg for Vec4 {
     }
 }
 
+impl From<[f32; 4]> for Vec4 {
+    fn from(d: [f32; 4]) -> Self {
+        Self{x: d[0], y: d[1], z: d[2], w: d[3]}
+    }
+}
+
 
 #[cfg(test)]
 mod tests {
